DENFIS.eng: DENFIS prediction function
Description
This function is an internal function for the prediction phase using the DENFIS method.
The user should use this function not directly, but with calling predict.
Usage
DENFIS.eng(object, newdata)
Value
a matrix of predicted values
Arguments
- object
the frbs model. See frbs-object.
- newdata
a matrix (\(m \times n\)) of data for the prediction process, where \(m\) is the number of instances and \(n\) is the number of input variables.